Loads the bipartite incidence matrix C where rows are bones (vertices) and columns are muscles (hyperedges). Entry C[i,j] = 1 indicates that muscle j attaches to bone i.
Loads the bipartite incidence matrix C where rows are bones (vertices) and columns are muscles (hyperedges). Entry C[i,j] = 1 indicates that muscle j attaches to bone i.