Detects communities in the projected muscle-muscle graph using the Louvain algorithm with a resolution parameter gamma.
Usage
mskCommunityDetect(hg = NULL, gamma = 4.3, type = c("muscle", "bone"))Detects communities in the projected muscle-muscle graph using the Louvain algorithm with a resolution parameter gamma.
mskCommunityDetect(hg = NULL, gamma = 4.3, type = c("muscle", "bone"))