Matches IMU sensor placement names to bones in the MSK hypergraph using a curated lookup table with fuzzy matching fallback. Supports naming conventions from Xsens, APDM, Shimmer, and generic body-segment labels.
Usage
imuToMSKMapping(
sensors,
hg = NULL,
method = c("exact", "fuzzy"),
threshold = 0.7
)Examples
if (FALSE) { # \dontrun{
mapping <- imuToMSKMapping(c("upper_arm", "thigh", "lumbar"))
} # }